==> haskell-http-types-0.9.1-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-http-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-types
version: 0.9.1
id: http-types-0.9.1-58mzFhAgNAb9DH0XYXjd5P
key: http-types-0.9.1-58mzFhAgNAb9DH0XYXjd5P
license: BSD3
copyright: (C) 2011 Aristid Breitkreuz
maintainer: aristidb@googlemail.com
homepage: https://github.com/aristidb/http-types
synopsis: Generic HTTP types for Haskell (for both client and server code).
description:
    Generic HTTP types for Haskell (for both client and server code).
category: Network, Web
author: Aristid Breitkreuz, Michael Snoyman
exposed: True
exposed-modules:
    Network.HTTP.Types Network.HTTP.Types.Header
    Network.HTTP.Types.Method Network.HTTP.Types.QueryLike
    Network.HTTP.Types.Status Network.HTTP.Types.URI
    Network.HTTP.Types.Version
abi: d9980cd419f0f1537966245d87c689a0
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http-types-0.9.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/http-types-0.9.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/http-types-0.9.1
hs-libraries: HShttp-types-0.9.1-58mzFhAgNAb9DH0XYXjd5P
depends:
    array-0.5.1.1 base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    case-insensitive-1.2.0.7-EiN1BqaYOWgBoqFOLWTmWz
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-http-types/html/http-types.haddock
haddock-html: /usr/share/doc/haskell-http-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-types-0.9.1-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-http-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-types
version: 0.9.1
id: http-types-0.9.1-86VKlfjfTunGvWNFdOLeV5
key: http-types-0.9.1-86VKlfjfTunGvWNFdOLeV5
license: BSD3
copyright: (C) 2011 Aristid Breitkreuz
maintainer: aristidb@googlemail.com
homepage: https://github.com/aristidb/http-types
synopsis: Generic HTTP types for Haskell (for both client and server code).
description:
    Generic HTTP types for Haskell (for both client and server code).
category: Network, Web
author: Aristid Breitkreuz, Michael Snoyman
exposed: True
exposed-modules:
    Network.HTTP.Types Network.HTTP.Types.Header
    Network.HTTP.Types.Method Network.HTTP.Types.QueryLike
    Network.HTTP.Types.Status Network.HTTP.Types.URI
    Network.HTTP.Types.Version
abi: ec2409c10db704bdd225696b54749bf8
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http-types-0.9.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/http-types-0.9.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/http-types-0.9.1
hs-libraries: HShttp-types-0.9.1-86VKlfjfTunGvWNFdOLeV5
depends:
    array-0.5.1.1 base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    case-insensitive-1.2.0.7-43Vuzc2uQwC59iyLU6pVOg
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-http-types/html/http-types.haddock
haddock-html: /usr/share/doc/haskell-http-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
